BootParameters

Struct BootParameters 

pub struct BootParameters {
    pub hosts: Vec<String>,
    pub macs: Option<Vec<String>>,
    pub nids: Option<Vec<u32>>,
    pub params: String,
    pub kernel: String,
    pub initrd: String,
    pub cloud_init: Option<Value>,
}

Fields

hosts: Vec<String>macs: Option<Vec<String>>nids: Option<Vec<u32>>params: Stringkernel: Stringinitrd: Stringcloud_init: Option<Value>

Implementations

Source

impl BootParameters

pub fn get_boot_image(&self) -> String

Returns the image id. This function may fail since it assumes kernel path has the following

pub fn update_boot_image(&mut self, new_image_id: &str) -> Result<bool, Error>

Update boot image in kernel boot parameters and also in kernel and initrd fields if exists. Otherwise nothing is changed. This method updates both kernel params related to NCN and also CN Returns a boolean that indicates if kernel parameters have change:

  • kernel parameter value changed
  • number of kernel parameters have changed
pub fn get_kernel_param_value(&self, key: &str) -> Option<String>

pub fn get_num_kernel_params(&self) -> usize

pub fn apply_kernel_params(&mut self, new_params: &str) -> bool

Apply a str of kernel parameters:

  • current kernel params will be ignored/removed and replaced by the new ones Returns true if kernel params have change
pub fn update_kernel_params(&mut self, new_params: &str) -> bool

Set a str of kernel parameters:

  • if kernel parameter already exists, then it will be updated
  • if kernel parameter does not exists, then it will be added Returns true if kernel params have change
pub fn update_kernel_param(&mut self, new_key: &str, new_value: &str) -> bool

Update kernel parameter. If kernel parameter exists, then it will be updated with new Note: This function won’t make any change to params without values (eg: ‘quiet’) since they don’t have values value. otherwise nothing will change

pub fn add_kernel_params(&mut self, new_kernel_params: &str) -> bool

Add a kernel parameter:

  • if kernel parameter does not exists, then it will be added, otherwise nothing will change Returns true if kernel params have change
pub fn delete_kernel_params(&mut self, kernel_params_to_delete: &str) -> bool

Delete kernel parameter. If kernel parameter exists, then it will be removed, otherwise nothing will be changed It accepts kernel params in format ‘key=value’ or just ‘key’ Returns true if kernel params have change