get_node_details

Function get_node_details 

pub async fn get_node_details(
    shasta_token: &str,
    shasta_base_url: &str,
    shasta_root_cert: &[u8],
    socks5_proxy: Option<&str>,
    xname_list: Vec<String>,
) -> Result<Vec<NodeDetails>, Error>
Get components data. Currently, CSM will throw an error if many xnames are sent in the request, therefore, this method will paralelize multiple calls, each with a batch of xnames