Functions
- get_
node_ details - Get components data. Currently, CSM will throw an error if many xnames are sent in the request, therefore, this method will paralelize multiple calls, each with a batch of xnames
- nodes_
to_ string_ format_ discrete_ columns - nodes_
to_ string_ format_ one_ line - validate_
nid_ format - Check if input is a NID
- validate_
nid_ format_ regex - Check if input is a NID
- validate_
nid_ format_ vec - Check if input is a NID
- validate_
target_ hsm_ members - Validate user has access to a list of HSM group members provided. HSM members user is asking for are taken from cli command Exit if user does not have access to any of the members provided. By not having access to a HSM members means, the node belongs to an HSM group which the user does not have access
- validate_
xname_ format - Validate xname is correct (it uses regex taken from HPE Cray CSM docs)
- validate_
xname_ format_ regex - Validate xname is correct (it uses regex taken from HPE Cray CSM docs)
- validate_
xname_ format_ vec - Validate xname is correct (it uses regex taken from HPE Cray CSM docs)
- validate_
xnames_ format_ and_ membership_ agaisnt_ single_ hsm - Validates a list of xnames. Checks xnames strings are valid If hsm_group_name_opt provided, then checks all xnames belongs to that hsm_group